@@ -6,7 +6,7 @@ import time
 import webbrowser
 from unidec.modules.html_writer import *
 
-version = "6.0.1"
+version = "6.0.2"
 
 
 def copy_config(config):
@@ -44,6 +44,7 @@ class UniDecEngine:
         self.altindexes = None
         self.matchindexes = None
         self.matchlist = None
+        self.html_str = ""
         self.initialize()
 
     def initialize(self):
@@ -608,29 +609,36 @@ class UniDecEngine:
                 print("Plot 4: %.2gs" % (tend - tstart))
             return plot
 
-    def gen_html_report(self, event=None, outfile=None, plots=None, interactive=False, open_in_browser=True):
+    def gen_html_report(self, event=None, outfile=None, plots=None, interactive=False, open_in_browser=True,
+                        results_string=None):
         """
         Generate an HTML report of the current UniDec run.
         :param event: Unused Event
+        :param outfile: Output file name. Default is None, which will use the default name.
         :param plots: List of plots to include in the report. Must be 2D with row and column format.
         :param interactive: If True, will include interactive plots. Default is False.
+        :param open_in_browser: If True, will open the report in the default browser. Default is True.
+        :param results_string: String to include in the report. Default is None.
         :return: None
         """
         if outfile is None:
             outfile = self.config.outfname + "_report.html"
         html_open(outfile)
-
-        html_title(self.config.filename, outfile)
+        self.html_str = ""
+        self.html_str += html_title(self.config.filename, outfile)
 
         peaks_df = self.pks.to_df()
         colors = [p.color for p in self.pks.peaks]
 
         if len(peaks_df) > 0:
-            df_to_html(peaks_df, outfile, colors=colors)
+            self.html_str += df_to_html(peaks_df, outfile, colors=colors)
 
         # array_to_html(np.transpose(self.matchlist), outfile,
         #              cols=["Measured Mass", "Theoretical Mass", "Error", "Match Name"])
 
+        if results_string is not None:
+            self.html_str += to_html_paragraph(results_string, outfile)
+
         if plots is None:
             plot = self.makeplot2(silent=True)
             plot2 = self.makeplot4(silent=True)
@@ -668,11 +676,12 @@ class UniDecEngine:
                 svg_grid.append(svg_row)
 
         svg_grid_string = wrap_to_grid(svg_grid, outfile)
+        self.html_str += svg_grid_string
 
         if interactive:
             for f in figure_list:
                 try:
-                    fig_to_html_mpld3(f, outfile)
+                    self.html_str += fig_to_html_mpld3(f, outfile)
                 except Exception:
                     pass
 
@@ -682,18 +691,19 @@ class UniDecEngine:
                 spectra_df.drop(["beta", "error", "iterations", "psig", "rsquared", "zsig", "mzsig", "length_mass",
                                  "length_mz", "time"], axis=1, inplace=True)
                 colors2 = self.data.get_colors()
-                df_to_html(spectra_df, outfile, colors=colors2)
+                self.html_str += df_to_html(spectra_df, outfile, colors=colors2)
         except Exception:
             pass
 
         config_dict = self.config.get_config_dict()
         config_htmlstring = dict_to_html(config_dict)
-        to_html_collapsible(config_htmlstring, title="UniDec Parameters", outfile=outfile, htmltext=True)
+        self.html_str += to_html_collapsible(config_htmlstring, title="UniDec Parameters", outfile=outfile,
+                                             htmltext=True)
 
         html_close(outfile)
 
         if open_in_browser:
             webbrowser.open_new_tab(outfile)
-            #os.system(self.config.opencommand + "\"" + outfile + "\"")
+            # os.system(self.config.opencommand + "\"" + outfile + "\"")
 
-        return outfile
\ No newline at end of file
+        return outfile
